YARP 2.3.62 (2014-02-19)                                              {#v2_3_62}
========================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.61...v2.3.62`):

```
    23	Paul Fitzpatrick <paulfitz@alum.mit.edu>
     3	Matteo Brunettini <matteo.brunettini@iit.it>
     2	Elena Ceseracciu <elena.ceseracciu@iit.it>
     1	Alberto Cardellino <alberto.cardellino@iit.it>
     1	Daniele E. Domenichelli <daniele.domenichelli@iit.it>
     1	Marco Randazzo <marco.randazzo@iit.it>
```
